import {expect} from 'chai'
import getOptimizelyConfig from '../../../src/vendors/optimizely/config'

describe('getOptimizelyConfig', () => {
  it('should return the config if optimizely is enabled', () => {
    const expectedOptimizelyConfig = {
      optimizely: {
        script: '//cdn.optimizely.com/js/5239650027.js',
        consents: {
          purposes: [10],
          specialFeatureOptions: []
        }
      }
    }

    const {config: optimizelyConfig} = getOptimizelyConfig({
      portal: 'es',
      path: '/employer/menu/my-menu.xhtml'
    })
    expect(optimizelyConfig).to.be.deep.equal(expectedOptimizelyConfig)
  })

  it('should return an empty object if optimizely is not enabled', () => {
    const expectedOptimizelyConfig = {}

    const {config: optimizelyConfig} = getOptimizelyConfig({
      portal: 'es',
      path: '/random-path-not-included'
    })

    expect(optimizelyConfig).to.be.deep.equal(expectedOptimizelyConfig)
  })
})
